@@ -344,6 +344,19 @@ context 'Extensions' do
       end
     end
 
+    test 'should not fail to unregister extension group if not registered' do
+      refute_nil Asciidoctor::Extensions.groups
+      assert_equal 0, Asciidoctor::Extensions.groups.size
+      Asciidoctor::Extensions.unregister :sample
+      assert_equal 0, Asciidoctor::Extensions.groups.size
+    end
+
+    test 'should not fail to unregister extension group if extension groups are not initialized' do
+      Asciidoctor::Extensions.remove_instance_variable :@groups
+      Asciidoctor::Extensions.unregister :sample
+      assert_equal 0, Asciidoctor::Extensions.groups.size
+    end
+
     test 'should raise NameError if extension class cannot be resolved from string' do
       begin
         Asciidoctor::Extensions.register do
@@ -392,6 +405,27 @@ context 'Extensions' do
       end
     end
 
+    test 'should reset registry if activate is called again' do
+      begin
+        Asciidoctor::Extensions.register :sample, SampleExtensionGroup
+        doc = Asciidoctor::Document.new
+        registry = Asciidoctor::Extensions::Registry.new
+        registry.activate doc
+        assert doc.attr? 'activate-method-called'
+        assert registry.preprocessors?
+        assert_equal 1, registry.preprocessors.size
+        assert_same doc, registry.document
+        doc = Asciidoctor::Document.new
+        registry.activate doc
+        assert doc.attr? 'activate-method-called'
+        assert registry.preprocessors?
+        assert_equal 1, registry.preprocessors.size
+        assert_same doc, registry.document
+      ensure
+        Asciidoctor::Extensions.unregister_all
+      end
+    end
+
     test 'should invoke extension block' do
       begin
         doc = Asciidoctor::Document.new
@@ -965,6 +999,28 @@ context 'Extensions' do
       end
     end
 
+    test 'should allow extension to promote paragraph to compound block' do
+      input = <<~'EOS'
+      [ex]
+      example
+      EOS
+      begin
+        Asciidoctor::Extensions.register do
+          block :ex do
+            on_context :paragraph
+            process do |parent, reader|
+              create_example_block parent, reader.read_lines, {}, content_model: :compound
+            end
+          end
+        end
+
+        output = convert_string_to_embedded input
+        assert_css '.exampleblock .paragraph', output, 1
+      ensure
+        Asciidoctor::Extensions.unregister_all
+      end
+    end
+
     test 'should invoke processor for custom block macro' do
       input = 'snippet::12345[mode=edit]'
 
@@ -1941,6 +1997,48 @@ context 'Extensions' do
       end
     end
 
+    test 'should raise exception if document processor extension does not provide process method' do
+      extension_registry = Asciidoctor::Extensions.create do
+        tree_processor do # rubocop:disable Lint/EmptyBlock
+        end
+      end
+      exception = assert_raises NoMethodError do
+        convert_string_to_embedded 'content', extension_registry: extension_registry
+      end
+      assert_match %r/No block specified to process tree processor extension at .*extensions_test\.rb:\d+/, exception.message
+    end
+
+    test 'should raise exception if syntax processor extension does not provide process method' do
+      extension_registry = Asciidoctor::Extensions.create do
+        block_macro :foo do # rubocop:disable Lint/EmptyBlock
+        end
+      end
+      exception = assert_raises NoMethodError do
+        convert_string_to_embedded 'foo::bar[]', extension_registry: extension_registry
+      end
+      assert_match %r/No block specified to process block macro extension at .*extensions_test\.rb:\d+/, exception.message
+    end
+
+    test 'should raise exception if syntax processor extension does not provide a name' do
+      macro_name = (Class.new String do
+        def to_sym
+          nil
+        end
+      end).new 'foo'
+      extension_registry = Asciidoctor::Extensions.create do
+        block_macro do
+          named macro_name
+          process do
+            nil
+          end
+        end
+      end
+      exception = assert_raises ArgumentError do
+        convert_string_to_embedded 'foo::bar[]', extension_registry: extension_registry
+      end
+      assert_match %r/No name specified for block macro extension at .*extensions_test\.rb:\d+/, exception.message
+    end
+
     test 'should raise an exception if mandatory target attribute is not provided for image block' do
       input = 'cat_in_sink::[]'
       exception = assert_raises ArgumentError do
