@@ -616,7 +616,7 @@ context 'Invoker' do
     assert_kind_of Asciidoctor::Converter::CompositeConverter, doc.converter
     selected = doc.converter.find_converter 'paragraph'
     assert_kind_of Asciidoctor::Converter::TemplateConverter, selected
-    assert_kind_of Tilt::HamlTemplate, selected.templates['paragraph']
+    assert_kind_of haml_template_class, selected.templates['paragraph']
   end
 
   test 'should load custom templates from multiple template directories' do
@@ -734,7 +734,7 @@ context 'Invoker' do
     assert_include '<p>IBM866:IBM866</p>', result
   end
 
-  test 'should not fail to load if call to Dir.home fails' do
+  test 'should not fail to load if call to Dir.home fails', unless: RUBY_ENGINE == 'truffleruby' do
     cmd = asciidoctor_cmd ['-r', (fixture_path 'undef-dir-home.rb')]
     result = run_command(cmd, '-e', '-o', '-', (fixture_path 'basic.adoc')) {|out| out.read }
     assert_include 'Body content', result
