@@ -46,6 +46,24 @@ context 'Manpage' do
       assert_includes output.lines, %(command, alt_command \\- does stuff\n)
     end
 
+    test 'should replace invalid characters in mantitle in info comment' do
+      input = <<~'EOS'
+      = foo\--<bar> (1)
+      Author Name
+      :doctype: manpage
+      :man manual: Foo Bar Manual
+      :man source: Foo Bar 1.0
+
+      == NAME
+
+      foo-bar - puts the foo in your bar
+      EOS
+
+      doc = Asciidoctor.load input, backend: :manpage, standalone: true
+      output = doc.convert
+      assert_includes output, %(Title: foo--bar\n)
+    end
+
     test 'should substitute attributes in manname and manpurpose in NAME section' do
       input = <<~'EOS'
       = {cmdname} (1)
@@ -128,8 +146,8 @@ context 'Manpage' do
         assert_equal ['cmd'], doc.attr('mannames')
         assert_equal '.1', doc.attr('outfilesuffix')
         output = doc.convert
-        refute logger.messages.empty?
-        assert_includes output, 'Title: cmd'
+        refute_empty logger.messages
+        assert_includes output, %(Title: cmd\n)
         assert output.end_with?('garbage in')
       end
     end
@@ -385,6 +403,18 @@ context 'Manpage' do
       output = Asciidoctor.convert input, backend: :manpage
       assert_includes output, '.SH "\(lqMAIN\(rq \fI<OPTIONS>\fP"'
     end
+
+    test 'should not uppercase monospace span in section titles' do
+      input = <<~EOS.chop
+      #{SAMPLE_MANPAGE_HEADER}
+
+      does stuff
+
+      == `show` option
+      EOS
+      output = Asciidoctor.convert input, backend: :manpage
+      assert_includes output, '.SH "\f(CRshow\fP OPTION"'
+    end
   end
 
   context 'Backslash' do
@@ -765,6 +795,17 @@ context 'Manpage' do
       assert output.end_with? %(\n.sp\n[signs point to yes])
     end
 
+    test 'should manify alt text of block image' do
+      input = <<~EOS.chop
+      #{SAMPLE_MANPAGE_HEADER}
+
+      image::rainbow.jpg["That's a double rainbow, otherwise known as rainbow{pp}!"]
+      EOS
+
+      output = Asciidoctor.convert input, backend: :manpage
+      assert output.end_with? %/\n.sp\n[That\\(cqs a double rainbow, otherwise known as rainbow++!]/
+    end
+
     test 'should replace inline image with alt text enclosed in square brackets' do
       input = <<~EOS.chop
       #{SAMPLE_MANPAGE_HEADER}
